==> seedsui-react-5.8.44.tgz: package/lib/Calendar/utils/slideX.js <==
import dayjs from 'dayjs';
import isDisabledDate from "./isDisabledDate";
import getDateRowIndex from "./getDateRowIndex";

// 左右滑动
function slideX(op, _ref) {
  var type = _ref.type,
    min = _ref.min,
    max = _ref.max,
    duration = _ref.duration,
    activeDate = _ref.activeDate,
    container = _ref.container,
    bodyX = _ref.bodyX,
    bodyY = _ref.bodyY,
    cellHeight = _ref.cellHeight;
  // 添加动画
  bodyX.style.transitionDuration = duration + 'ms';

  // 滑动位置
  var translateX = -container.clientWidth;
  // 切换后日期
  var newActiveDate = activeDate;

  // 左滑动
  if (op === 'previous') {
    // 位置
    translateX = 0;

    // 日期
    if (type === 'month') {
      newActiveDate = dayjs(activeDate).subtract(1, 'month').toDate();
    } else {
      newActiveDate = dayjs(activeDate).subtract(7, 'day').toDate();
    }
  }
  // 右滑动
  else if (op === 'next') {
    // 位置
    translateX = -container.clientWidth * 2;

    // 日期
    if (type === 'month') {
      newActiveDate = dayjs(activeDate).add(1, 'month').toDate();
    } else {
      newActiveDate = dayjs(activeDate).add(7, 'day').toDate();
    }
  }

  // 使用禁用当天作为选中项
  var disabledDate = isDisabledDate(newActiveDate, {
    min: min,
    max: max
  });

  // 禁止日期
  if (disabledDate) {
    var errMsg = '禁止访问' + disabledDate.format('YYYY年MM月DD日') + '前的日期';
    console.log(errMsg);
    newActiveDate = activeDate;
    translateX = -container.clientWidth;
  }

  // 横向移动面板
  bodyX.style.transform = 'translateX(' + translateX + 'px)';

  // 动画执行结束后刷新日历
  return new Promise(function (resolve) {
    setTimeout(function () {
      bodyX.style.transitionDuration = '0ms';
      resolve(newActiveDate);

      // 复原位置
      setTimeout(function () {
        bodyX.style.transform = 'translateX(' + -container.clientWidth + 'px)';

        // 月视图时, 需要还原位置
        var translateY = 0;
        if (type === 'month') {
          translateY = 0;
        }
        // 周视图时, 需要移动竖向位置
        else {
          var weekRowIndex = getDateRowIndex(newActiveDate);
          translateY = -weekRowIndex * cellHeight;
        }
        bodyY.style.transform = 'translateY(' + translateY + 'px)';
        bodyY.setAttribute('data-translateY', translateY);
      }, 0);
    }, duration);
  });
}
export default slideX;

==> seedsui-react-5.8.59.tgz: package/lib/Calendar/utils/slideX.js <==
import dayjs from 'dayjs';
import isDisabledDate from "./isDisabledDate";
import Months from "./Months";

// 左右滑动
function slideX(op, _ref) {
  var type = _ref.type,
    min = _ref.min,
    max = _ref.max,
    duration = _ref.duration,
    weekStart = _ref.weekStart,
    activeDate = _ref.activeDate,
    container = _ref.container,
    bodyX = _ref.bodyX,
    bodyY = _ref.bodyY,
    cellHeight = _ref.cellHeight;
  // 添加动画
  bodyX.style.transitionDuration = duration + 'ms';

  // 滑动位置
  var translateX = -container.clientWidth;
  // 切换后日期
  var newActiveDate = activeDate;

  // 左滑动
  if (op === 'previous') {
    // 位置
    translateX = 0;

    // 日期
    if (type === 'month') {
      newActiveDate = dayjs(activeDate).subtract(1, 'month').toDate();
    } else {
      newActiveDate = dayjs(activeDate).subtract(7, 'day').toDate();
    }
  }
  // 右滑动
  else if (op === 'next') {
    // 位置
    translateX = -container.clientWidth * 2;

    // 日期
    if (type === 'month') {
      newActiveDate = dayjs(activeDate).add(1, 'month').toDate();
    } else {
      newActiveDate = dayjs(activeDate).add(7, 'day').toDate();
    }
  }

  // 使用禁用当天作为选中项
  var disabledDate = isDisabledDate(newActiveDate, {
    min: min,
    max: max
  });

  // 禁止日期
  if (disabledDate) {
    console.log('禁止访问' + new Date().toLocaleDateString() + '前的日期');
    newActiveDate = activeDate;
    translateX = -container.clientWidth;
  }

  // 横向移动面板
  bodyX.style.transform = 'translateX(' + translateX + 'px)';

  // 动画执行结束后刷新日历
  return new Promise(function (resolve) {
    setTimeout(function () {
      bodyX.style.transitionDuration = '0ms';
      resolve(newActiveDate);

      // 复原位置
      setTimeout(function () {
        bodyX.style.transform = 'translateX(' + -container.clientWidth + 'px)';

        // 月视图时, 需要还原位置
        var translateY = 0;
        if (type === 'month') {
          translateY = 0;
        }
        // 周视图时, 需要移动竖向位置
        else {
          var activeDateRowIndex = Months.getDateRowIndex(newActiveDate, weekStart);
          translateY = -activeDateRowIndex * cellHeight;
        }
        bodyY.style.transform = 'translateY(' + translateY + 'px)';
        bodyY.setAttribute('data-translateY', translateY);
      }, 0);
    }, duration);
  });
}
export default slideX;
